<?php

namespace Realestate\Property\Forms;

use Litepie\Form\FormInterpreter;

class Property extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('property/property/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('property/property/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('property/property'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('property/property'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('property/property'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('property/property'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('property::property.label.name'),
                "placeholder" => trans('property::property.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('property::property.label.created_at'),
            'name' => trans('property::property.label.name'),
            'status' => trans('property::property.label.status'),
        ];
        self::$groups = [
            'main' => trans('property::property.groups.main'),
            'details' => trans('property::property.groups.details'),
            'images' => trans('property::property.groups.images'),
            'settings' => trans('property::property.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('property::property.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('property::property.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('property::property.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('property::property.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'country_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.country_id'),
                "placeholder" => trans('property::property.placeholder.country_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'state_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.state_id'),
                "placeholder" => trans('property::property.placeholder.state_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'district_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.district_id'),
                "placeholder" => trans('property::property.placeholder.district_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'city_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.city_id'),
                "placeholder" => trans('property::property.placeholder.city_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'location_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.location_id'),
                "placeholder" => trans('property::property.placeholder.location_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'category_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.category_id'),
                "placeholder" => trans('property::property.placeholder.category_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'sort_order' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.sort_order'),
                "placeholder" => trans('property::property.placeholder.sort_order'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'code' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.code'),
                "placeholder" => trans('property::property.placeholder.code'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.title'),
                "placeholder" => trans('property::property.placeholder.title'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'description' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.description'),
                "placeholder" => trans('property::property.placeholder.description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'published' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.published'),
                "placeholder" => trans('property::property.placeholder.published'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'publish_status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.publish_status'),
                "placeholder" => trans('property::property.placeholder.publish_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'year' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.year'),
                "placeholder" => trans('property::property.placeholder.year'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'property_for' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.property_for'),
                "placeholder" => trans('property::property.placeholder.property_for'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'label' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.label'),
                "placeholder" => trans('property::property.placeholder.label'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'price' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.price'),
                "placeholder" => trans('property::property.placeholder.price'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'plan_name' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.plan_name'),
                "placeholder" => trans('property::property.placeholder.plan_name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'amount' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.amount'),
                "placeholder" => trans('property::property.placeholder.amount'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'pay_frequency' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.pay_frequency'),
                "placeholder" => trans('property::property.placeholder.pay_frequency'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'images' => [
                "element" => 'file',
                "type" => 'images',
                "label" => trans('property::property.label.images'),
                "placeholder" => trans('property::property.placeholder.images'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'area' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('property::property.label.area'),
                "placeholder" => trans('property::property.placeholder.area'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'size_prefix' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.size_prefix'),
                "placeholder" => trans('property::property.placeholder.size_prefix'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'land_area_size_prefix' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.land_area_size_prefix'),
                "placeholder" => trans('property::property.placeholder.land_area_size_prefix'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'area_type' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.area_type'),
                "placeholder" => trans('property::property.placeholder.area_type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'owner_type' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.owner_type'),
                "placeholder" => trans('property::property.placeholder.owner_type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'bedrooms' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.bedrooms'),
                "placeholder" => trans('property::property.placeholder.bedrooms'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'bathrooms' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.bathrooms'),
                "placeholder" => trans('property::property.placeholder.bathrooms'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'garages' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.garages'),
                "placeholder" => trans('property::property.placeholder.garages'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'garage_size' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('property::property.label.garage_size'),
                "placeholder" => trans('property::property.placeholder.garage_size'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'water_source' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.water_source'),
                "placeholder" => trans('property::property.placeholder.water_source'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'furnishing' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.furnishing'),
                "placeholder" => trans('property::property.placeholder.furnishing'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'no_balcony' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.no_balcony'),
                "placeholder" => trans('property::property.placeholder.no_balcony'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'address' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.address'),
                "placeholder" => trans('property::property.placeholder.address'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'neighbourhood' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.neighbourhood'),
                "placeholder" => trans('property::property.placeholder.neighbourhood'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'zip_code' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.zip_code'),
                "placeholder" => trans('property::property.placeholder.zip_code'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'locality' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.locality'),
                "placeholder" => trans('property::property.placeholder.locality'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'features' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.features'),
                "placeholder" => trans('property::property.placeholder.features'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'slider' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.slider'),
                "placeholder" => trans('property::property.placeholder.slider'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'featured' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.featured'),
                "placeholder" => trans('property::property.placeholder.featured'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'hotprop_order' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.hotprop_order'),
                "placeholder" => trans('property::property.placeholder.hotprop_order'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'premium' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.premium'),
                "placeholder" => trans('property::property.placeholder.premium'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'email_alert' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.email_alert'),
                "placeholder" => trans('property::property.placeholder.email_alert'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'photo_count' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.photo_count'),
                "placeholder" => trans('property::property.placeholder.photo_count'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'validity' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.validity'),
                "placeholder" => trans('property::property.placeholder.validity'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'visibility' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.visibility'),
                "placeholder" => trans('property::property.placeholder.visibility'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'video_embed' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.video_embed'),
                "placeholder" => trans('property::property.placeholder.video_embed'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'payment_status' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('property::property.label.payment_status'),
                "placeholder" => trans('property::property.placeholder.payment_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'latitude' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.latitude'),
                "placeholder" => trans('property::property.placeholder.latitude'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'longitude' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.longitude'),
                "placeholder" => trans('property::property.placeholder.longitude'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'map_embed' => [
                "element" => 'html_editor',
                "type" => 'html_editor',
                "label" => trans('property::property.label.map_embed'),
                "placeholder" => trans('property::property.placeholder.map_embed'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'posting_type' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.posting_type'),
                "placeholder" => trans('property::property.placeholder.posting_type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'listing_plan' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.listing_plan'),
                "placeholder" => trans('property::property.placeholder.listing_plan'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'plan_visibility' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.plan_visibility'),
                "placeholder" => trans('property::property.placeholder.plan_visibility'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'contact_mail' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.contact_mail'),
                "placeholder" => trans('property::property.placeholder.contact_mail'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'parking_no' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.parking_no'),
                "placeholder" => trans('property::property.placeholder.parking_no'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'website' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.website'),
                "placeholder" => trans('property::property.placeholder.website'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'phone' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.phone'),
                "placeholder" => trans('property::property.placeholder.phone'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'mobile' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.mobile'),
                "placeholder" => trans('property::property.placeholder.mobile'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'contact_name' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.contact_name'),
                "placeholder" => trans('property::property.placeholder.contact_name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'region' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.region'),
                "placeholder" => trans('property::property.placeholder.region'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'category_id1' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('property::property.label.category_id1'),
                "placeholder" => trans('property::property.placeholder.category_id1'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'prop_age' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.prop_age'),
                "placeholder" => trans('property::property.placeholder.prop_age'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'prop_status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.prop_status'),
                "placeholder" => trans('property::property.placeholder.prop_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'overview' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.overview'),
                "placeholder" => trans('property::property.placeholder.overview'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'video' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.video'),
                "placeholder" => trans('property::property.placeholder.video'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'video_status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.video_status'),
                "placeholder" => trans('property::property.placeholder.video_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'facilities' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.facilities'),
                "placeholder" => trans('property::property.placeholder.facilities'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'landmarks' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.landmarks'),
                "placeholder" => trans('property::property.placeholder.landmarks'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'sellunit' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.sellunit'),
                "placeholder" => trans('property::property.placeholder.sellunit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'price_negotiable' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.price_negotiable'),
                "placeholder" => trans('property::property.placeholder.price_negotiable'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'admin_status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.admin_status'),
                "placeholder" => trans('property::property.placeholder.admin_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'paid_status' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.paid_status'),
                "placeholder" => trans('property::property.placeholder.paid_status'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'direct_contact' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.direct_contact'),
                "placeholder" => trans('property::property.placeholder.direct_contact'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'posted_date' => [
                "element" => 'date_picker',
                "type" => 'date_picker',
                "label" => trans('property::property.label.posted_date'),
                "placeholder" => trans('property::property.placeholder.posted_date'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'expire_date' => [
                "element" => 'date_picker',
                "type" => 'date_picker',
                "label" => trans('property::property.label.expire_date'),
                "placeholder" => trans('property::property.placeholder.expire_date'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'manage_type' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.manage_type'),
                "placeholder" => trans('property::property.placeholder.manage_type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'buildup_area' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.buildup_area'),
                "placeholder" => trans('property::property.placeholder.buildup_area'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'buildup_unit' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.buildup_unit'),
                "placeholder" => trans('property::property.placeholder.buildup_unit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'plot_area' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.plot_area'),
                "placeholder" => trans('property::property.placeholder.plot_area'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'plot_unit' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.plot_unit'),
                "placeholder" => trans('property::property.placeholder.plot_unit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'land_area' => [
                "element" => 'decimal',
                "type" => 'decimal',
                "label" => trans('property::property.label.land_area'),
                "placeholder" => trans('property::property.placeholder.land_area'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'land_unit' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.land_unit'),
                "placeholder" => trans('property::property.placeholder.land_unit'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.meta_title'),
                "placeholder" => trans('property::property.placeholder.meta_title'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_keyword' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.meta_keyword'),
                "placeholder" => trans('property::property.placeholder.meta_keyword'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_description' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.meta_description'),
                "placeholder" => trans('property::property.placeholder.meta_description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'city1' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('property::property.label.city1'),
                "placeholder" => trans('property::property.placeholder.city1'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
